@@ -2,60 +2,94 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2009 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, and version detection.                                       *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
-# * misunderstandings, we consider an application to constitute a           *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                * 
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
+# * misunderstandings, we interpret that term as broadly as copyright law   *
+# * allows.  For example, we consider an application to constitute a        *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
-# * interpretation of derived works with some common examples.  Our         *
-# * interpretation applies only to Nmap--we don't speak for other people's  *
-# * GPL works.                                                              *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates as well as helping to     *
-# * fund the continued development of Nmap technology.  Please email        *
-# * sales@insecure.com for further information.                             *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
-# * listed in the included COPYING.OpenSSL file, and distribute linked      *
-# * combinations including the two. You must obey the GNU GPL in all        *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -64,24 +98,24 @@
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
-# * Insecure.Org development mailing lists, it is assumed that you are      *
-# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
-# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
-# * will always be available Open Source, but this is important because the *
-# * inability to relicense code has caused devastating problems for other   *
-# * Free Software projects (such as KDE and NASM).  We also occasionally    *
-# * relicense the code to third parties as discussed above.  If you wish to *
-# * specify special license conditions of your contributions, just say so   *
-# * when you send them.                                                     *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
+# * Insecure.Org development mailing lists, or checking them into the Nmap  *
+# * source code repository, it is understood (unless you specify otherwise) *
+# * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+# * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+# * code.  Nmap will always be available Open Source, but this is important *
+# * because the inability to relicense code has caused devastating problems *
+# * for other Free Software projects (such as KDE and NASM).  We also       *
+# * occasionally relicense the code to third parties as discussed above.    *
+# * If you wish to specify special license conditions of your               *
+# * contributions, just say so when you send them.                          *
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -90,14 +124,12 @@ import xml.sax.saxutils
 from xml.sax.xmlreader import AttributesImpl as Attributes
 
 
-
 def convert_to_utf8(text):
     """
     """
     return text.encode('utf8', 'replace')
 
 
-
 class XMLNode:
     """
     """
@@ -109,70 +141,56 @@ class XMLNode:
         self.__attrs = dict()
         self.__children = []
 
-
     def set_text(self, text):
         """
         """
         self.__text = text
 
-
     def get_text(self):
         """
         """
         return self.__text
 
-
     def set_name(self, name):
         """
         """
         self.__name = name
 
-
     def get_name(self):
         """
         """
         return self.__name
 
-
     def add_attr(self, key, value):
         """
         """
         self.__attrs[key] = value
 
-
     def add_child(self, child):
         """
         """
         self.__children.append(child)
 
-
     def get_keys(self):
         """
         """
         return self.__attrs.keys()
 
-
     def get_attr(self, attr):
         """
         """
-        if self.__attrs.has_key(attr):
-            return self.__attrs[attr]
-
-        return None
-
+        return self.__attrs.get(attr)
 
     def get_attrs(self):
         """
         """
         return self.__attrs
 
-
     def get_children(self):
         """
         """
         return self.__children
 
-
     def query_children(self, name, attr, value, first=False, deep=False):
         """
         """
@@ -182,7 +200,7 @@ class XMLNode:
 
             if child.get_name() == name:
 
-                if child.get_attrs().has_key(attr):
+                if attr in child.get_attrs():
 
                     c_value = child.get_attr(attr)
 
@@ -193,7 +211,7 @@ class XMLNode:
 
                 c_result = child.query_children(name, attr, value, first, deep)
 
-                if c_result != None:
+                if c_result is not None:
 
                     if first:
                         return c_result
@@ -209,7 +227,6 @@ class XMLNode:
 
         return result
 
-
     def search_children(self, name, first=False, deep=False):
         """
         """
@@ -228,7 +245,7 @@ class XMLNode:
 
                 c_result = child.search_children(name, first, deep)
 
-                if c_result != None and c_result != []:
+                if c_result is not None and c_result != []:
 
                     if first:
                         return c_result
@@ -242,7 +259,6 @@ class XMLNode:
         return result
 
 
-
 class XMLWriter(xml.sax.saxutils.XMLGenerator):
     """
     """
@@ -253,13 +269,11 @@ class XMLWriter(xml.sax.saxutils.XMLGenerator):
 
         self.__root = root
 
-
     def set_root(self, root):
         """
         """
         self.__root = root
 
-
     def write(self):
         """
         """
@@ -267,7 +281,6 @@ class XMLWriter(xml.sax.saxutils.XMLGenerator):
         self.write_xml_node([self.__root])
         self.endDocument()
 
-
     def write_xml_node(self, root):
         """
         """
@@ -283,7 +296,6 @@ class XMLWriter(xml.sax.saxutils.XMLGenerator):
             self.endElement(child.get_name())
 
 
-
 class XMLReader(xml.sax.ContentHandler):
     """
     """
@@ -296,41 +308,35 @@ class XMLReader(xml.sax.ContentHandler):
         self.__file = file
         self.__root = None
 
-        self.__parser = xml.sax.make_parser();
-        self.__parser.setContentHandler(self);
-
+        self.__parser = xml.sax.make_parser()
+        self.__parser.setContentHandler(self)
 
     def set_file(self, file, root):
         """
         """
         self.__file = file
 
-
     def get_file(self):
         """
         """
         return self.__file
 
-
     def get_root(self):
         """
         """
         return self.__root
 
-
     def parse(self):
         """
         """
-        if self.__file != None:
+        if self.__file is not None:
             self.__parser.parse(self.__file)
 
-
     def startDocument(self):
         """
         """
         pass
 
-
     def startElement(self, name, attrs):
         """
         """
@@ -345,12 +351,11 @@ class XMLReader(xml.sax.ContentHandler):
         if len(self.__status) > 0:
             self.__status[-1].add_child(node)
 
-        if self.__root == None:
+        if self.__root is None:
             self.__root = node
 
         self.__status.append(node)
 
-
     def endElement(self, name):
         """
         """
@@ -359,20 +364,17 @@ class XMLReader(xml.sax.ContentHandler):
         self.__text = ""
         self.__status.pop()
 
-
     def endDocument(self):
         """
         """
         pass
 
-
     def characters(self, text):
         """
         """
         self.__text += text
 
 
-
 if __name__ == "__main__":
 
     import sys
