@@ -2,62 +2,94 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, version detection, and the Nmap Scripting Engine.            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
 # * misunderstandings, we interpret that term as broadly as copyright law   *
 # * allows.  For example, we consider an application to constitute a        *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap, as well as other software we distribute under this       *
-# * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
-# * but is meant to clarify our interpretation of derived works with some   *
-# * common examples.  Our interpretation applies only to Nmap--we don't     *
-# * speak for other people's GPL works.                                     *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -66,8 +98,8 @@
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
 # * source code repository, it is understood (unless you specify otherwise) *
 # * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -81,10 +113,9 @@
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -96,29 +127,30 @@ from radialnet.bestwidgets.boxes import *
 from radialnet.bestwidgets.expanders import BWExpander
 from radialnet.bestwidgets.labels import *
 from radialnet.bestwidgets.textview import *
+import zenmapCore.I18N
 
 
-PORTS_HEADER = [_('Port'), _('Protocol'), _('State'), _('Service'), _('Method')]
+PORTS_HEADER = [
+        _('Port'), _('Protocol'), _('State'), _('Service'), _('Method')]
 EXTRAPORTS_HEADER = [_('Count'), _('State'), _('Reasons')]
 
-SERVICE_COLORS = {'open'            : '#ffd5d5',
-                  'closed'          : '#d5ffd5',
-                  'filtered'        : '#ffffd5',
-                  'unfiltered'      : '#ffd5d5',
-                  'open|filtered'   : '#ffd5d5',
-                  'closed|filtered' : '#d5ffd5'}
+SERVICE_COLORS = {'open':            '#ffd5d5',
+                  'closed':          '#d5ffd5',
+                  'filtered':        '#ffffd5',
+                  'unfiltered':      '#ffd5d5',
+                  'open|filtered':   '#ffd5d5',
+                  'closed|filtered': '#d5ffd5'}
 UNKNOWN_SERVICE_COLOR = '#d5d5d5'
 
 TRACE_HEADER = [_('TTL'), _('RTT'), _('IP'), _('Hostname')]
 
-TRACE_TEXT = _("""\
-Traceroute on port <b>%s/%s</b> totalized <b>%d</b> known hops.\
-""")
+TRACE_TEXT = _(
+    "Traceroute on port <b>%s/%s</b> totalized <b>%d</b> known hops.")
 
 NO_TRACE_TEXT = _("No traceroute information available.")
 
-HOP_COLOR = {'known'   : '#ffffff',
-             'unknown' : '#cccccc'}
+HOP_COLOR = {'known':   '#ffffff',
+             'unknown': '#cccccc'}
 
 SYSTEM_ADDRESS_TEXT = "[%s] %s"
 
@@ -131,6 +163,7 @@ TCP_SEQ_NOTE = _("""\
 <b>*</b> TCP sequence <i>index</i> equal to %d and <i>difficulty</i> is "%s".\
 """)
 
+
 def get_service_color(state):
     color = SERVICE_COLORS.get(state)
     if color is None:
@@ -151,7 +184,6 @@ class NodeNotebook(gtk.Notebook):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -166,7 +198,6 @@ class NodeNotebook(gtk.Notebook):
         self.append_page(self.__trace_page, BWLabel(_('Traceroute')))
 
 
-
 class ServicesPage(gtk.Notebook):
     """
     """
@@ -182,7 +213,6 @@ class ServicesPage(gtk.Notebook):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -225,17 +255,9 @@ class ServicesPage(gtk.Notebook):
 
             color = get_service_color(port['state']['state'])
 
-            if port['service'].has_key('name'):
-                service_name = port['service']['name']
+            service_name = port['service'].get('name', _('<unknown>'))
 
-            else:
-                service_name = _('<unknown>')
-
-            if port['service'].has_key('method'):
-                service_method = port['service']['method']
-
-            else:
-                service_method = _('<none>')
+            service_method = port['service'].get('method', _('<none>'))
 
             reference = self.__ports_store.append(None,
                                                   [port['id'],
@@ -299,7 +321,7 @@ class ServicesPage(gtk.Notebook):
 
             column = gtk.TreeViewColumn(PORTS_HEADER[i],
                                         self.__cell,
-                                        text = i)
+                                        text=i)
 
             self.__ports_column.append(column)
 
@@ -307,9 +329,9 @@ class ServicesPage(gtk.Notebook):
             self.__ports_column[i].set_resizable(True)
             self.__ports_column[i].set_sort_column_id(i)
             self.__ports_column[i].set_attributes(self.__cell,
-                                                  text = i,
-                                                  background = 5,
-                                                  editable = 6)
+                                                  text=i,
+                                                  background=5,
+                                                  editable=6)
 
             self.__ports_treeview.append_column(self.__ports_column[i])
 
@@ -333,12 +355,9 @@ class ServicesPage(gtk.Notebook):
             color = get_service_color(xports['state'])
             number_of_xports += xports['count']
 
-            reference = self.__xports_store.append(None,
-                                                   [xports['count'],
-                                                    xports['state'],
-                                                    ", ".join(xports['reason']),
-                                                    color,
-                                                    True])
+            reference = self.__xports_store.append(
+                    None, [xports['count'], xports['state'],
+                    ", ".join(xports['reason']), color, True])
 
             for xreason in xports['all_reason']:
                 self.__xports_store.append(reference,
@@ -354,7 +373,7 @@ class ServicesPage(gtk.Notebook):
 
             column = gtk.TreeViewColumn(EXTRAPORTS_HEADER[i],
                                         self.__cell,
-                                        text = i)
+                                        text=i)
 
             self.__xports_column.append(column)
 
@@ -362,9 +381,9 @@ class ServicesPage(gtk.Notebook):
             self.__xports_column[i].set_resizable(True)
             self.__xports_column[i].set_sort_column_id(i)
             self.__xports_column[i].set_attributes(self.__cell,
-                                                   text = i,
-                                                   background = 3,
-                                                   editable = 4)
+                                                   text=i,
+                                                   background=3,
+                                                   editable=4)
 
             self.__xports_treeview.append_column(self.__xports_column[i])
 
@@ -380,7 +399,6 @@ class ServicesPage(gtk.Notebook):
         if len(self.__text) > 0:
             self.__select_combobox.set_active(0)
 
-
     def __change_text_value(self, widget):
         """
         """
@@ -402,7 +420,6 @@ class SystemPage(BWScrolledWindow):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -430,7 +447,7 @@ class SystemPage(BWScrolledWindow):
             params = address['type'], address['addr']
             address_text = SYSTEM_ADDRESS_TEXT % params
 
-            if address['vendor'] != None and address['vendor'] != '':
+            if address['vendor'] is not None and address['vendor'] != '':
                 address_text += " (%s)" % address['vendor']
 
             self.__address_list.append_text(address_text)
@@ -442,7 +459,7 @@ class SystemPage(BWScrolledWindow):
                                       xoptions=gtk.FILL)
         self.__general.bw_attach_next(self.__address_list, yoptions=gtk.FILL)
 
-        if self.__node.get_info('hostnames') != None:
+        if self.__node.get_info('hostnames') is not None:
 
             self.__hostname_label = BWSectionLabel(_('Hostname:'))
             self.__hostname_list = gtk.combo_box_entry_new_text()
@@ -461,7 +478,7 @@ class SystemPage(BWScrolledWindow):
             self.__general.bw_attach_next(self.__hostname_list,
                                           yoptions=gtk.FILL)
 
-        if self.__node.get_info('uptime') != None:
+        if self.__node.get_info('uptime') is not None:
 
             self.__uptime_label = BWSectionLabel(_('Last boot:'))
 
@@ -485,16 +502,17 @@ class SystemPage(BWScrolledWindow):
 
         sequences = self.__node.get_info('sequences')
         if len(sequences) > 0:
-            self.__sequences_frame.bw_add(self.__create_sequences_widget(sequences))
+            self.__sequences_frame.bw_add(
+                    self.__create_sequences_widget(sequences))
 
         # operating system information widgets
         self.__os = gtk.Notebook()
 
         os = self.__node.get_info('os')
 
-        if os != None:
+        if os is not None:
 
-            if os.has_key('matches'):
+            if 'matches' in os:
 
                 self.__match_scroll = BWScrolledWindow()
 
@@ -519,15 +537,15 @@ class SystemPage(BWScrolledWindow):
 
                     column = gtk.TreeViewColumn(OSMATCH_HEADER[i],
                                                 self.__cell,
-                                                text = i)
+                                                text=i)
 
                     self.__match_column.append(column)
 
                     self.__match_column[i].set_reorderable(True)
                     self.__match_column[i].set_resizable(True)
                     self.__match_column[i].set_attributes(self.__cell,
-                                                          text = i,
-                                                          editable = 3)
+                                                          text=i,
+                                                          editable=3)
 
                     self.__match_column[i].set_sort_column_id(i)
                     self.__match_treeview.append_column(self.__match_column[i])
@@ -536,7 +554,7 @@ class SystemPage(BWScrolledWindow):
 
                 self.__os.append_page(self.__match_scroll, BWLabel(_('Match')))
 
-            if os.has_key('classes'):
+            if 'classes' in os:
 
                 self.__class_scroll = BWScrolledWindow()
 
@@ -551,10 +569,7 @@ class SystemPage(BWScrolledWindow):
 
                 for os_class in os['classes']:
 
-                    os_gen = ''
-
-                    if os_class.has_key('os_gen'):
-                        os_gen = os_class['os_gen']
+                    os_gen = os_class.get('os_gen', '')
 
                     self.__class_store.append([os_class['accuracy'],
                                                os_class['vendor'],
@@ -569,15 +584,15 @@ class SystemPage(BWScrolledWindow):
 
                     column = gtk.TreeViewColumn(OSCLASS_HEADER[i],
                                                 self.__cell,
-                                                text = i)
+                                                text=i)
 
                     self.__class_column.append(column)
 
                     self.__class_column[i].set_reorderable(True)
                     self.__class_column[i].set_resizable(True)
                     self.__class_column[i].set_attributes(self.__cell,
-                                                          text = i,
-                                                          editable = 5)
+                                                          text=i,
+                                                          editable=5)
 
                     self.__class_column[i].set_sort_column_id(i)
                     self.__class_treeview.append_column(self.__class_column[i])
@@ -599,7 +614,7 @@ class SystemPage(BWScrolledWindow):
 
             self.__fp_vbox = BWVBox()
 
-            if os.has_key('used_ports'):
+            if 'used_ports' in os:
 
                 used_ports = os['used_ports']
 
@@ -661,7 +676,8 @@ class SystemPage(BWScrolledWindow):
             tcp_note.set_selectable(True)
             tcp_note.set_line_wrap(False)
             tcp_note.set_alignment(1.0, 0.5)
-            tcp_note.set_markup(TCP_SEQ_NOTE % (tcp['index'], tcp['difficulty']))
+            tcp_note.set_markup(
+                    TCP_SEQ_NOTE % (tcp['index'], tcp['difficulty']))
 
             table.attach(tcp_note, 0, 3, 4, 5)
 
@@ -688,7 +704,7 @@ class SystemPage(BWScrolledWindow):
 
             table.attach(tcp_ts_class, 1, 2, 3, 4)
 
-            if tcp_ts['values'] != None:
+            if tcp_ts['values'] is not None:
 
                 tcp_ts_values = gtk.combo_box_entry_new_text()
 
@@ -702,8 +718,6 @@ class SystemPage(BWScrolledWindow):
         return table
 
 
-
-
 class TraceroutePage(BWVBox):
     """
     """
@@ -717,7 +731,6 @@ class TraceroutePage(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -774,23 +787,22 @@ class TraceroutePage(BWVBox):
                                                HOP_COLOR['unknown'],
                                                True])
 
-
             self.__trace_column = list()
 
             for i in range(len(TRACE_HEADER)):
 
                 column = gtk.TreeViewColumn(TRACE_HEADER[i],
                                             self.__cell,
-                                            text = i)
+                                            text=i)
 
                 self.__trace_column.append(column)
 
                 self.__trace_column[i].set_reorderable(True)
                 self.__trace_column[i].set_resizable(True)
                 self.__trace_column[i].set_attributes(self.__cell,
-                                                      text = i,
-                                                      background = 4,
-                                                      editable = 5)
+                                                      text=i,
+                                                      background=4,
+                                                      editable=5)
 
                 self.__trace_treeview.append_column(self.__trace_column[i])
 
