@@ -3,60 +3,94 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2009 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, and version detection.                                       *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
-# * misunderstandings, we consider an application to constitute a           *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                * 
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
+# * misunderstandings, we interpret that term as broadly as copyright law   *
+# * allows.  For example, we consider an application to constitute a        *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
-# * interpretation of derived works with some common examples.  Our         *
-# * interpretation applies only to Nmap--we don't speak for other people's  *
-# * GPL works.                                                              *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates as well as helping to     *
-# * fund the continued development of Nmap technology.  Please email        *
-# * sales@insecure.com for further information.                             *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
-# * listed in the included COPYING.OpenSSL file, and distribute linked      *
-# * combinations including the two. You must obey the GNU GPL in all        *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -65,24 +99,24 @@
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
-# * Insecure.Org development mailing lists, it is assumed that you are      *
-# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
-# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
-# * will always be available Open Source, but this is important because the *
-# * inability to relicense code has caused devastating problems for other   *
-# * Free Software projects (such as KDE and NASM).  We also occasionally    *
-# * relicense the code to third parties as discussed above.  If you wish to *
-# * specify special license conditions of your contributions, just say so   *
-# * when you send them.                                                     *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
+# * Insecure.Org development mailing lists, or checking them into the Nmap  *
+# * source code repository, it is understood (unless you specify otherwise) *
+# * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+# * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+# * code.  Nmap will always be available Open Source, but this is important *
+# * because the inability to relicense code has caused devastating problems *
+# * for other Free Software projects (such as KDE and NASM).  We also       *
+# * occasionally relicense the code to third parties as discussed above.    *
+# * If you wish to specify special license conditions of your               *
+# * contributions, just say so when you send them.                          *
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -92,7 +126,8 @@ import webbrowser
 
 from zenmapGUI.higwidgets.higdialogs import HIGDialog
 from zenmapGUI.higwidgets.higwindows import HIGWindow
-from zenmapGUI.higwidgets.higboxes import HIGVBox, HIGHBox, hig_box_space_holder
+from zenmapGUI.higwidgets.higboxes import HIGVBox, HIGHBox, \
+        hig_box_space_holder
 from zenmapGUI.higwidgets.higbuttons import HIGButton
 from zenmapGUI.higwidgets.hignotebooks import HIGNotebook
 from zenmapGUI.higwidgets.higscrollers import HIGScrolledWindow
@@ -107,6 +142,7 @@ import zenmapCore.I18N
 # For escaping text in marked-up labels.
 from xml.sax.saxutils import escape
 
+
 class _program_entry(gtk.VBox):
     """A little box containing labels with a program's name and
     description and a clickable link to its web site."""
@@ -115,7 +151,7 @@ class _program_entry(gtk.VBox):
     # web site button.
     NAME_WEB_SITE_SPACING = 20
 
-    def __init__(self, name = None, web_site = None, description = None):
+    def __init__(self, name=None, web_site=None, description=None):
         gtk.VBox.__init__(self)
 
         self.hbox = gtk.HBox(False, self.NAME_WEB_SITE_SPACING)
@@ -123,7 +159,9 @@ class _program_entry(gtk.VBox):
 
         if name is not None:
             name_label = gtk.Label()
-            name_label.set_markup("<span size=\"large\" weight=\"bold\">%s</span>" % escape(name))
+            name_label.set_markup(
+                    '<span size="large" weight="bold">%s</span>' % escape(
+                        name))
             self.hbox.pack_start(name_label, False)
 
         if web_site is not None:
@@ -146,41 +184,44 @@ class _program_entry(gtk.VBox):
     def _link_button_open(self, widget):
         webbrowser.open(widget.get_uri())
 
+
 class About(HIGDialog):
     """An about dialog showing information about the program. It is meant to
     have roughly the same feel as gtk.AboutDialog."""
     def __init__(self):
         HIGDialog.__init__(self)
-        self.set_title(_("About %s and %s") % (NMAP_DISPLAY_NAME, APP_DISPLAY_NAME))
+        self.set_title(_("About %s and %s") % (
+            NMAP_DISPLAY_NAME, APP_DISPLAY_NAME))
 
         self.vbox.set_border_width(12)
         self.vbox.set_spacing(12)
 
         label = gtk.Label()
-        label.set_markup("<span size=\"xx-large\" weight=\"bold\">%s %s</span>" \
-% (escape(APP_DISPLAY_NAME), escape(VERSION)))
+        label.set_markup(
+                '<span size="xx-large" weight="bold">%s %s</span>' % (
+                    escape(APP_DISPLAY_NAME), escape(VERSION)))
         label.set_selectable(True)
         self.vbox.pack_start(label)
 
         label = gtk.Label()
-        label.set_markup("<span size=\"small\">%s</span>" \
-% (escape(APP_COPYRIGHT)))
+        label.set_markup(
+                '<span size="small">%s</span>' % (escape(APP_COPYRIGHT)))
         self.vbox.pack_start(label)
 
-        entry = _program_entry(NMAP_DISPLAY_NAME, NMAP_WEB_SITE, _("""\
-%s is a free and open source utility for network exploration and security \
-auditing.""") % NMAP_DISPLAY_NAME)
+        entry = _program_entry(NMAP_DISPLAY_NAME, NMAP_WEB_SITE, _(
+            "%s is a free and open source utility for network exploration "
+            "and security auditing.") % NMAP_DISPLAY_NAME)
         self.vbox.pack_start(entry)
 
-        entry = _program_entry(APP_DISPLAY_NAME, APP_WEB_SITE, _("""\
-%s is a multi-platform graphical %s frontend and results viewer. It was \
-originally derived from %s.""") \
-% (APP_DISPLAY_NAME, NMAP_DISPLAY_NAME, UMIT_DISPLAY_NAME))
+        entry = _program_entry(APP_DISPLAY_NAME, APP_WEB_SITE, _(
+        "%s is a multi-platform graphical %s frontend and results viewer. "
+        "It was originally derived from %s.") % (
+            APP_DISPLAY_NAME, NMAP_DISPLAY_NAME, UMIT_DISPLAY_NAME))
         self.vbox.pack_start(entry)
 
-        entry = _program_entry(UMIT_DISPLAY_NAME, UMIT_WEB_SITE, _("""\
-%s is an %s GUI created as part of the Nmap/Google Summer of Code program.""") \
-% (UMIT_DISPLAY_NAME, NMAP_DISPLAY_NAME))
+        entry = _program_entry(UMIT_DISPLAY_NAME, UMIT_WEB_SITE, _(
+            "%s is an %s GUI created as part of the Nmap/Google Summer "
+            "of Code program.") % (UMIT_DISPLAY_NAME, NMAP_DISPLAY_NAME))
         button = gtk.Button(_("%s credits") % UMIT_DISPLAY_NAME)
         button.connect("clicked", self._show_umit_credits)
         entry.hbox.pack_start(button, False)
@@ -212,32 +253,35 @@ originally derived from %s.""") \
             return
 
         self._umit_credits_dialog = UmitCredits()
+
         def credits_destroyed(widget):
             # Mark that the credits dialog has been destroyed.
             self._umit_credits_dialog = None
+
         self._umit_credits_dialog.connect("destroy", credits_destroyed)
         self._umit_credits_dialog.show_all()
 
+
 class UmitCredits(HIGWindow):
     def __init__(self):
         HIGWindow.__init__(self)
         self.set_title(_("%s credits") % UMIT_DISPLAY_NAME)
-        self.set_size_request(-1,250)
+        self.set_size_request(-1, 250)
         self.set_position(gtk.WIN_POS_CENTER)
-        
+
         self.__create_widgets()
         self.__packing()
         self.set_text()
-    
+
     def __create_widgets(self):
         self.vbox = HIGVBox()
         self.hbox = HIGHBox()
         self.notebook = HIGNotebook()
         self.btn_close = HIGButton(stock=gtk.STOCK_CLOSE)
-        
+
         self.written_by_scroll = HIGScrolledWindow()
         self.written_by_text = HIGTextView()
-        
+
         self.design_scroll = HIGScrolledWindow()
         self.design_text = HIGTextView()
 
@@ -246,7 +290,7 @@ class UmitCredits(HIGWindow):
 
         self.contributors_scroll = HIGScrolledWindow()
         self.contributors_text = HIGTextView()
-        
+
         self.translation_scroll = HIGScrolledWindow()
         self.translation_text = HIGTextView()
 
@@ -258,20 +302,26 @@ class UmitCredits(HIGWindow):
         self.vbox.set_spacing(12)
         self.vbox._pack_expand_fill(self.notebook)
         self.vbox._pack_noexpand_nofill(self.hbox)
-        
+
         self.hbox._pack_expand_fill(hig_box_space_holder())
         self.hbox._pack_noexpand_nofill(self.btn_close)
-        
-        self.notebook.append_page(self.written_by_scroll, gtk.Label(_("Written by")))
-        self.notebook.append_page(self.design_scroll, gtk.Label(_("Design")))
-        self.notebook.append_page(self.soc2007_scroll, gtk.Label(_("SoC 2007")))
-        self.notebook.append_page(self.contributors_scroll, gtk.Label(_("Contributors")))
-        self.notebook.append_page(self.translation_scroll, gtk.Label(_("Translation")))
-        self.notebook.append_page(self.nokia_scroll, gtk.Label(_("Maemo")))
-        
+
+        self.notebook.append_page(
+                self.written_by_scroll, gtk.Label(_("Written by")))
+        self.notebook.append_page(
+                self.design_scroll, gtk.Label(_("Design")))
+        self.notebook.append_page(
+                self.soc2007_scroll, gtk.Label(_("SoC 2007")))
+        self.notebook.append_page(
+                self.contributors_scroll, gtk.Label(_("Contributors")))
+        self.notebook.append_page(
+                self.translation_scroll, gtk.Label(_("Translation")))
+        self.notebook.append_page(
+                self.nokia_scroll, gtk.Label(_("Maemo")))
+
         self.written_by_scroll.add(self.written_by_text)
         self.written_by_text.set_wrap_mode(gtk.WRAP_NONE)
-        
+
         self.design_scroll.add(self.design_text)
         self.design_text.set_wrap_mode(gtk.WRAP_NONE)
 
@@ -280,19 +330,19 @@ class UmitCredits(HIGWindow):
 
         self.contributors_scroll.add(self.contributors_text)
         self.contributors_text.set_wrap_mode(gtk.WRAP_NONE)
-        
+
         self.translation_scroll.add(self.translation_text)
         self.translation_text.set_wrap_mode(gtk.WRAP_NONE)
-        
+
         self.nokia_scroll.add(self.nokia_text)
         self.nokia_text.set_wrap_mode(gtk.WRAP_NONE)
 
-        self.btn_close.connect('clicked', lambda x,y=None:self.destroy())
-    
+        self.btn_close.connect('clicked', lambda x, y=None: self.destroy())
+
     def set_text(self):
         b = self.written_by_text.get_buffer()
         b.set_text("""Adriano Monteiro Marques <py.adriano@gmail.com>""")
-        
+
         b = self.design_text.get_buffer()
         b.set_text("""Operating System and Vulnerability Icons:
 Takeshi Alexandre Gondo <sinistrofumanchu@yahoo.com.br>
@@ -363,11 +413,11 @@ Luis Antonio Bastião Silva <luis.kop@gmail.com>
 Initial attempt on Maemo port:
 Adriano Monteiro Marques <py.adriano@gmail.com>
 Osvaldo Santana Neto <osantana@gmail.com>""")
-        
+
         b = self.translation_text.get_buffer()
         b.set_text("""Brazilian Portuguese:
 Adriano Monteiro Marques <py.adriano@gmail.com>""")
-        
+
         b = self.nokia_text.get_buffer()
         b.set_text("""Adriano Monteiro Marques <py.adriano@gmail.com>""")
 
