@@ -3,62 +3,94 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, version detection, and the Nmap Scripting Engine.            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
 # * misunderstandings, we interpret that term as broadly as copyright law   *
 # * allows.  For example, we consider an application to constitute a        *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap, as well as other software we distribute under this       *
-# * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
-# * but is meant to clarify our interpretation of derived works with some   *
-# * common examples.  Our interpretation applies only to Nmap--we don't     *
-# * speak for other people's GPL works.                                     *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -67,8 +99,8 @@
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
 # * source code repository, it is understood (unless you specify otherwise) *
 # * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -82,10 +114,9 @@
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -93,7 +124,6 @@ import errno
 import gtk
 import gobject
 import os
-import re
 import time
 import xml.sax
 
@@ -114,7 +144,8 @@ from zenmapGUI.ScanScanListPage import ScanScanListPage
 from zenmapGUI.ScansListStore import ScansListStore
 from zenmapGUI.TopologyPage import TopologyPage
 
-from zenmapCore.NetworkInventory import NetworkInventory, FilteredNetworkInventory
+from zenmapCore.NetworkInventory import NetworkInventory,\
+        FilteredNetworkInventory
 from zenmapCore.NmapCommand import NmapCommand
 from zenmapCore.UmitConf import CommandProfile, ProfileNotFound, is_maemo
 from zenmapCore.NmapParser import NmapParser
@@ -126,6 +157,7 @@ import zenmapCore.I18N
 # How often the live output view refreshes, in milliseconds.
 NMAP_OUTPUT_REFRESH_INTERVAL = 1000
 
+
 class ScanInterface(HIGVBox):
     """ScanInterface contains the scan toolbar and the scan results. Each
     ScanInterface represents a single NetworkInventory as well as a set of
@@ -173,20 +205,26 @@ class ScanInterface(HIGVBox):
                                       scan_interface=self)
         self.host_view_selection = self.scan_result.get_host_selection()
         self.service_view_selection = self.scan_result.get_service_selection()
-        self.host_view_selection.connect('changed', self.host_selection_changed)
-        self.service_view_selection.connect('changed', self.service_selection_changed)
+        self.host_view_selection.connect(
+                'changed', self.host_selection_changed)
+        self.service_view_selection.connect(
+                'changed', self.service_selection_changed)
         host_page = self.scan_result.scan_result_notebook.open_ports.host
-        host_page.host_view.get_selection().connect('changed', self.service_host_selection_changed)
-        self.host_view_selection.connect('changed', self.host_selection_changed)
+        host_page.host_view.get_selection().connect(
+                'changed', self.service_host_selection_changed)
+        self.host_view_selection.connect(
+                'changed', self.host_selection_changed)
 
-        self.scan_result.scan_result_notebook.nmap_output.connect("changed", self._displayed_scan_change_cb)
-        self.scan_result.scan_result_notebook.scans_list.remove_button.connect("clicked", self._remove_scan_cb)
+        self.scan_result.scan_result_notebook.nmap_output.connect(
+                "changed", self._displayed_scan_change_cb)
+        self.scan_result.scan_result_notebook.scans_list.remove_button.connect(
+                "clicked", self._remove_scan_cb)
 
         # The hosts dict maps hostnames (as returned by HostInfo.get_hostname)
         # to HostInfo objects.
         self.hosts = {}
-        # The services dict maps service names ("http") to lists of dicts of the
-        # form
+        # The services dict maps service names ("http") to lists of dicts of
+        # the form
         # {'host': <HostInfo object>, 'hostname': u'example.com',
         #  'port_state': u'open', 'portid': u'22', 'protocol': u'tcp',
         #  'service_conf': u'10', 'service_extrainfo': u'protocol 2.0',
@@ -205,7 +243,8 @@ class ScanInterface(HIGVBox):
         self._pack_noexpand_nofill(self.top_box)
         self._pack_expand_fill(self.scan_result)
 
-        self.scan_result.scan_result_notebook.scans_list.cancel_button.connect("clicked", self._cancel_scans_list_cb)
+        self.scan_result.scan_result_notebook.scans_list.cancel_button.connect(
+                "clicked", self._cancel_scans_list_cb)
         self.update_cancel_button()
 
         # Create the filter GUI
@@ -240,16 +279,18 @@ class ScanInterface(HIGVBox):
         # Restart the timer to start the filter.
         if self.filter_timeout_id:
             gobject.source_remove(self.filter_timeout_id)
-        self.filter_timeout_id = gobject.timeout_add(self.FILTER_DELAY, self.filter_hosts, filter_bar.get_filter_string())
+        self.filter_timeout_id = gobject.timeout_add(
+                self.FILTER_DELAY, self.filter_hosts,
+                filter_bar.get_filter_string())
 
     def filter_hosts(self, filter_string):
         start = time.clock()
         self.inventory.apply_filter(filter_string)
-        filter_time = time.clock() - start;
+        filter_time = time.clock() - start
         # Update the gui
         start = time.clock()
         self.update_ui()
-        gui_time = time.clock() - start;
+        gui_time = time.clock() - start
 
         if filter_time + gui_time > 0.0:
             log.debug("apply_filter %g ms  update_ui %g ms (%.0f%% filter)" %
@@ -271,8 +312,8 @@ class ScanInterface(HIGVBox):
         return len(self.jobs)
 
     def select_default_profile(self):
-        """Select a "default" profile. Currently this is defined to be the first
-        profile."""
+        """Select a "default" profile. Currently this is defined to be the
+        first profile."""
         if len(self.toolbar.profile_entry.get_model()) > 0:
             self.toolbar.profile_entry.set_active(0)
 
@@ -283,21 +324,22 @@ class ScanInterface(HIGVBox):
     def __create_toolbar(self):
         self.toolbar = ScanToolbar()
 
-        self.target_entry_changed_handler = \
-            self.toolbar.target_entry.connect('changed', self._target_entry_changed)
+        self.target_entry_changed_handler = self.toolbar.target_entry.connect(
+                'changed', self._target_entry_changed)
         self.profile_entry_changed_handler = \
-            self.toolbar.profile_entry.connect('changed', self._profile_entry_changed)
+            self.toolbar.profile_entry.connect(
+                    'changed', self._profile_entry_changed)
 
         self.toolbar.scan_button.connect('clicked', self.start_scan_cb)
         self.toolbar.cancel_button.connect('clicked', self._cancel_scan_cb)
 
-
     def __create_command_toolbar(self):
         self.command_toolbar = ScanCommandToolbar()
-        self.command_toolbar.command_entry.connect('activate',
-                                    lambda x: self.toolbar.scan_button.clicked())
+        self.command_toolbar.command_entry.connect(
+                'activate', lambda x: self.toolbar.scan_button.clicked())
         self.command_entry_changed_handler = \
-            self.command_toolbar.command_entry.connect('changed', self._command_entry_changed)
+            self.command_toolbar.command_entry.connect(
+                    'changed', self._command_entry_changed)
 
     def _command_entry_changed(self, editable):
         ops = NmapOptions()
@@ -347,23 +389,29 @@ class ScanInterface(HIGVBox):
     def set_command_quiet(self, command_string):
         """Set the command used by this scan interface, ignoring any further
         "changed" signals."""
-        self.command_toolbar.command_entry.handler_block(self.command_entry_changed_handler)
+        self.command_toolbar.command_entry.handler_block(
+                self.command_entry_changed_handler)
         self.command_toolbar.set_command(command_string)
-        self.command_toolbar.command_entry.handler_unblock(self.command_entry_changed_handler)
+        self.command_toolbar.command_entry.handler_unblock(
+                self.command_entry_changed_handler)
 
     def set_target_quiet(self, target_string):
         """Set the target string used by this scan interface, ignoring any
         further "changed" signals."""
-        self.toolbar.target_entry.handler_block(self.target_entry_changed_handler)
+        self.toolbar.target_entry.handler_block(
+                self.target_entry_changed_handler)
         self.toolbar.set_selected_target(target_string)
-        self.toolbar.target_entry.handler_unblock(self.target_entry_changed_handler)
+        self.toolbar.target_entry.handler_unblock(
+                self.target_entry_changed_handler)
 
     def set_profile_name_quiet(self, profile_name):
         """Set the profile name used by this scan interface, ignoring any
         further "changed" signals."""
-        self.toolbar.profile_entry.handler_block(self.profile_entry_changed_handler)
+        self.toolbar.profile_entry.handler_block(
+                self.profile_entry_changed_handler)
         self.toolbar.set_selected_profile(profile_name)
-        self.toolbar.profile_entry.handler_unblock(self.profile_entry_changed_handler)
+        self.toolbar.profile_entry.handler_unblock(
+                self.profile_entry_changed_handler)
 
     def start_scan_cb(self, widget=None):
         target = self.toolbar.selected_target
@@ -381,14 +429,17 @@ class ScanInterface(HIGVBox):
             except IOError, e:
                 # We failed to save target_list.txt; treat it as read-only.
                 # Probably it's owned by root and this is a normal user.
-                log.debug(">>> Error saving %s: %s" % (Path.target_list, str(e)))
+                log.debug(">>> Error saving %s: %s" % (
+                    Path.target_list, str(e)))
 
         if command == '':
-            warn_dialog = HIGAlertDialog(message_format=_("Empty Nmap Command"),
-                                         secondary_text=_("There is no command to  \
-execute. Maybe the selected/typed profile doesn't exist. Please, check the profile name \
-or type the nmap command you would like to execute."),
-                                         type=gtk.MESSAGE_ERROR)
+            warn_dialog = HIGAlertDialog(
+                    message_format=_("Empty Nmap Command"),
+                    secondary_text=_("There is no command to execute. "
+                        "Maybe the selected/typed profile doesn't exist. "
+                        "Please check the profile name or type the nmap "
+                        "command you would like to execute."),
+                    type=gtk.MESSAGE_ERROR)
             warn_dialog.run()
             warn_dialog.destroy()
             return
@@ -432,12 +483,12 @@ or type the nmap command you would like to execute."),
             if entry.running:
                 self.cancel_scan(entry.command)
             try:
-                # Remove it from the inentory if present.
+                # Remove it from the inventory if present.
                 self.inventory.remove_scan(entry.parsed)
             except ValueError:
                 pass
-            # Create TreeRowReferences because those persist while we change the
-            # model.
+            # Create TreeRowReferences because those persist while we change
+            # the model.
             selected_refs.append(gtk.TreeRowReference(model, path))
         # Delete the entries from the ScansListStore.
         for ref in selected_refs:
@@ -469,7 +520,7 @@ or type the nmap command you would like to execute."),
         self.jobs.remove(command)
         self.update_cancel_button()
 
-    def execute_command(self, command, target = None, profile = None):
+    def execute_command(self, command, target=None, profile=None):
         """Run the given Nmap command. Add it to the list of running scans.
         Schedule a timer to refresh the output and check the scan for
         completion."""
@@ -484,21 +535,27 @@ or type the nmap command you would like to execute."),
                 # Handle ENOENT specially.
                 if e.errno == errno.ENOENT:
                     # nmap_command_path comes from zenmapCore.NmapCommand.
-                    text += "\n\n" + _("This means that the nmap executable was not found in your system PATH, which is") + "\n\n" + os.getenv("PATH", _("<undefined>"))
+                    text += "\n\n%s\n\n%s" % (
+                            _("This means that the nmap executable was "
+                                "not found in your system PATH, which is"),
+                            os.getenv("PATH", _("<undefined>"))
+                            )
                     path_env = os.getenv("PATH")
                     if path_env is None:
                         default_paths = []
                     else:
                         default_paths = path_env.split(os.pathsep)
                     extra_paths = get_extra_executable_search_paths()
-                    extra_paths = [p for p in extra_paths if p not in default_paths]
+                    extra_paths = [p for p in extra_paths if (
+                        p not in default_paths)]
                     if len(extra_paths) > 0:
                         if len(extra_paths) == 1:
                             text += "\n\n" + _("plus the extra directory")
                         else:
                             text += "\n\n" + _("plus the extra directories")
                         text += "\n\n" + os.pathsep.join(extra_paths)
-            warn_dialog = HIGAlertDialog(message_format=_("Error executing command"),
+            warn_dialog = HIGAlertDialog(
+                message_format=_("Error executing command"),
                 secondary_text=text, type=gtk.MESSAGE_ERROR)
             warn_dialog.run()
             warn_dialog.destroy()
@@ -515,7 +572,8 @@ or type the nmap command you would like to execute."),
         self.scan_result.refresh_nmap_output()
 
         # Add a timeout function
-        self.verify_thread_timeout_id = gobject.timeout_add(NMAP_OUTPUT_REFRESH_INTERVAL, self.verify_execution)
+        self.verify_thread_timeout_id = gobject.timeout_add(
+            NMAP_OUTPUT_REFRESH_INTERVAL, self.verify_execution)
 
     def verify_execution(self):
         """This is a callback that is called periodically to refresh the output
@@ -566,12 +624,12 @@ or type the nmap command you would like to execute."),
             except:
                 st = None
             if st is None or st.st_size > 0:
-                warn_dialog = HIGAlertDialog(message_format = _("Parse error"),
-                    secondary_text = _(u"""\
-There was an error while parsing the XML file generated from the scan:
-
-%s\
-""") % str(e), type = gtk.MESSAGE_ERROR)
+                warn_dialog = HIGAlertDialog(
+                        message_format=_("Parse error"),
+                        secondary_text=_(
+                            "There was an error while parsing the XML file "
+                            "generated from the scan:\n\n%s""") % str(e),
+                        type=gtk.MESSAGE_ERROR)
                 warn_dialog.run()
                 warn_dialog.destroy()
         else:
@@ -581,12 +639,12 @@ There was an error while parsing the XML file generated from the scan:
             try:
                 self.inventory.add_scan(parsed)
             except Exception, e:
-                warn_dialog = HIGAlertDialog(message_format = _("Cannot merge scan"),
-                    secondary_text = _(u"""\
-There was an error while merging the new scan's XML:
-
-%s\
-""") % str(e), type = gtk.MESSAGE_ERROR)
+                warn_dialog = HIGAlertDialog(
+                        message_format=_("Cannot merge scan"),
+                        secondary_text=_(
+                            "There was an error while merging the new scan's "
+                            "XML:\n\n%s") % str(e),
+                        type=gtk.MESSAGE_ERROR)
                 warn_dialog.run()
                 warn_dialog.destroy()
         parsed.set_xml_is_temp(command.xml_is_temp)
@@ -655,27 +713,29 @@ There was an error while merging the new scan's XML:
                 if name not in self.services.keys():
                     self.services[name] = []
 
-                hs = {"host":host, "hostname":hostname}
+                hs = {"host": host, "hostname": hostname}
                 hs.update(service)
 
                 self.services[name].append(hs)
 
             self.hosts[hostname] = host
 
-        # If the host and service selection is empty or has become empty, select
-        # the first host if there is at least one.
-        if len(self.host_view_selection.get_selected_rows()[1]) == 0 \
-            and len(self.service_view_selection.get_selected_rows()[1]) == 0 \
-            and len(self.scan_result.scan_host_view.host_list) > 0:
-            self.host_view_selection.select_iter(self.scan_result.scan_host_view.host_list.get_iter_first())
+        # If the host and service selection is empty or has become empty,
+        # select the first host if there is at least one.
+        if (len(self.service_view_selection.get_selected_rows()[1]) == 0 and
+                len(self.host_view_selection.get_selected_rows()[1]) == 0 and
+                len(self.scan_result.scan_host_view.host_list) > 0):
+            self.host_view_selection.select_iter(
+                self.scan_result.scan_host_view.host_list.get_iter_first())
 
         self.filter_bar.set_information_text(_("%d/%d hosts shown") %
             (len(self.inventory.get_hosts_up()),
              len(NetworkInventory.get_hosts_up(self.inventory))))
 
-        if self.scan_result.scan_host_view.mode == ScanHostsView.HOST_MODE:
+        mode = self.scan_result.scan_host_view.mode
+        if mode == ScanHostsView.HOST_MODE:
             self.refresh_port_output()
-        elif self.scan_result.scan_host_view.mode == ScanHostsView.SERVICE_MODE:
+        elif mode == ScanHostsView.SERVICE_MODE:
             self.refresh_host_output()
 
     def refresh_port_output(self):
@@ -683,11 +743,12 @@ There was an error while merging the new scan's XML:
         current host selection."""
         self.scan_result.scan_result_notebook.port_mode()
 
-        model_host_list, selection = self.host_view_selection.get_selected_rows()
+        model_host_list, selection = \
+                self.host_view_selection.get_selected_rows()
         host_objs = []
         for i in selection:
             hostname = model_host_list[i[0]][2]
-            if self.hosts.has_key(hostname):
+            if hostname in self.hosts:
                 host_objs.append(self.hosts[hostname])
 
         if len(host_objs) == 1:
@@ -701,11 +762,12 @@ There was an error while merging the new scan's XML:
         current service selection."""
         self.scan_result.scan_result_notebook.host_mode()
 
-        model_service_list, selection = self.service_view_selection.get_selected_rows()
+        model_service_list, selection = \
+                self.service_view_selection.get_selected_rows()
         serv_objs = []
         for i in selection:
             key = model_service_list[i[0]][0]
-            if self.services.has_key(key):
+            if key in self.services:
                 serv_objs.append(self.services[key])
 
         # Each element of serv_objs is a list of port dicts.
@@ -714,12 +776,14 @@ There was an error while merging the new scan's XML:
         else:
             servs = []
             for s in serv_objs:
-                servs.append({"service_name":s[0]["service_name"], "ports": s})
+                servs.append({
+                    "service_name": s[0]["service_name"],
+                    "ports": s})
             self.set_multiple_service_host(servs)
 
     def host_selection_changed(self, widget):
         self.refresh_port_output()
-        # Switch nmap output to show first host occourrence
+        # Switch nmap output to show first host occurrence
         model, selection = self.host_view_selection.get_selected_rows()
         for path in selection:
             self.go_to_host(model[path][2])
@@ -760,7 +824,8 @@ There was an error while merging the new scan's XML:
         """Sets the comment on a host from the contents of the comment text
         entry."""
         buff = widget.get_buffer()
-        host.comment = buff.get_text(buff.get_start_iter(), buff.get_end_iter())
+        host.comment = buff.get_text(
+                buff.get_start_iter(), buff.get_end_iter())
         for scan in self.inventory.get_scans():
             if host in scan.get_hosts():
                 scan.unsaved = True
@@ -772,8 +837,10 @@ There was an error while merging the new scan's XML:
         pages = []
         for host in hosts:
             page = ScanHostDetailsPage(host)
-            page.host_details.comment_txt_vw.connect("insert-at-cursor", self._save_comment, host)
-            page.host_details.comment_txt_vw.connect("focus-out-event", self._save_comment, host)
+            page.host_details.comment_txt_vw.connect(
+                    "insert-at-cursor", self._save_comment, host)
+            page.host_details.comment_txt_vw.connect(
+                    "focus-out-event", self._save_comment, host)
             pages.append(page)
         return pages
 
@@ -802,9 +869,9 @@ There was an error while merging the new scan's XML:
         host_page.thaw()
 
     def set_multiple_host_port(self, host_list):
-        """Change the "Ports / Hosts" tab to show the port output for all of the
-        hosts in host_list. When multiple hosts are selected, the port output
-        for each is contained in an expander."""
+        """Change the "Ports / Hosts" tab to show the port output for all of
+        the hosts in host_list. When multiple hosts are selected, the port
+        output for each is contained in an expander."""
         host_page = self.scan_result.scan_result_notebook.open_ports.host
         host_page.switch_port_to_tree_store()
 
@@ -815,19 +882,22 @@ There was an error while merging the new scan's XML:
         host_page.thaw()
 
     def set_multiple_service_host(self, service_list):
-        """Change the "Ports / Hosts" tab to show the hosts associated with each
-        of the services in service_list. Each element of service_list must be a
-        dict with the keys "service_name" and "ports". When multiple services
-        are selected, the hosts for each are contained in an expander."""
+        """Change the "Ports / Hosts" tab to show the hosts associated with
+        each of the services in service_list. Each element of service_list must
+        be a dict with the keys "service_name" and "ports". When multiple
+        services are selected, the hosts for each are contained in an
+        expander."""
         host_page = self.scan_result.scan_result_notebook.open_ports.host
         host_page.switch_host_to_tree_store()
 
         host_page.freeze()
         host_page.clear_host_tree()
         for service in service_list:
-            host_page.add_to_host_tree(service["service_name"], service["ports"])
+            host_page.add_to_host_tree(
+                    service["service_name"], service["ports"])
         host_page.thaw()
 
+
 class ScanResult(gtk.HPaned):
     """This is the pane that has the "Host"/"Service" column (ScanHostsView) on
     the left and the "Nmap Output"/"Ports / Hosts"/etc. (ScanResultNotebook) on
@@ -884,7 +954,8 @@ class ScanResultNotebook(HIGNotebook):
 
         self.__create_widgets(inventory, scans_store)
 
-        self.scans_list.scans_list.connect("row-activated", self._scan_row_activated)
+        self.scans_list.scans_list.connect(
+                "row-activated", self._scan_row_activated)
 
         self.append_page(self.nmap_output_page, gtk.Label(_('Nmap Output')))
         self.append_page(self.open_ports_page, gtk.Label(_('Ports / Hosts')))
