@@ -3,62 +3,94 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, version detection, and the Nmap Scripting Engine.            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
 # * misunderstandings, we interpret that term as broadly as copyright law   *
 # * allows.  For example, we consider an application to constitute a        *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap, as well as other software we distribute under this       *
-# * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
-# * but is meant to clarify our interpretation of derived works with some   *
-# * common examples.  Our interpretation applies only to Nmap--we don't     *
-# * speak for other people's GPL works.                                     *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -67,8 +99,8 @@
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
 # * source code repository, it is understood (unless you specify otherwise) *
 # * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -82,10 +114,9 @@
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -97,12 +128,14 @@ from zenmapGUI.higwidgets.higtables import HIGTable
 from zenmapCore.UmitLogging import log
 import zenmapCore.I18N
 
+
 def findout_service_icon(port_info):
     if port_info["port_state"] in ["open", "open|filtered"]:
         return gtk.STOCK_YES
     else:
         return gtk.STOCK_NO
 
+
 def get_version_string(d):
     """Get a human-readable version string from the dict d. The keys used in d
     are "service_product", "service_version", and "service_extrainfo" (all are
@@ -117,38 +150,45 @@ def get_version_string(d):
         result.append("(" + d["service_extrainfo"] + ")")
     return " ".join(result)
 
+
 def get_addrs(host):
     if host is None:
         return None
     return host.get_addrs_for_sort()
 
+
 def cmp_addrs(host_a, host_b):
     return cmp(get_addrs(host_a), get_addrs(host_b))
 
+
 def cmp_port_list_addr(model, iter_a, iter_b):
     host_a = model.get_value(iter_a, 0)
     host_b = model.get_value(iter_b, 0)
     return cmp_addrs(host_a, host_b)
 
+
 def cmp_port_tree_addr(model, iter_a, iter_b):
     host_a = model.get_value(iter_a, 0)
     host_b = model.get_value(iter_b, 0)
     return cmp_addrs(host_a, host_b)
 
+
 def cmp_host_list_addr(model, iter_a, iter_b):
     host_a = model.get_value(iter_a, 2)
     host_b = model.get_value(iter_b, 2)
     return cmp_addrs(host_a, host_b)
 
+
 def cmp_host_tree_addr(model, iter_a, iter_b):
     host_a = model.get_value(iter_a, 2)
     host_b = model.get_value(iter_b, 2)
     return cmp_addrs(host_a, host_b)
 
+
 class ScanOpenPortsPage(gtk.ScrolledWindow):
     def __init__(self):
         gtk.ScrolledWindow.__init__(self)
-        self.set_policy(gtk.POLICY_AUTOMATIC,gtk.POLICY_AUTOMATIC)
+        self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
 
         self.__create_widgets()
 
@@ -157,6 +197,7 @@ class ScanOpenPortsPage(gtk.ScrolledWindow):
     def __create_widgets(self):
         self.host = HostOpenPorts()
 
+
 class HostOpenPorts(HIGVBox):
     def __init__(self):
         HIGVBox.__init__(self)
@@ -172,8 +213,10 @@ class HostOpenPorts(HIGVBox):
         # host hostname icon port protocol state service version
         # The hostname column is shown only when more than one host is selected
         # (hence port_tree not port_list is used).
-        self.port_list = gtk.ListStore(object, str, str, int, str, str, str, str)
-        self.port_tree = gtk.TreeStore(object, str, str, int, str, str, str, str)
+        self.port_list = gtk.ListStore(
+                object, str, str, int, str, str, str, str)
+        self.port_tree = gtk.TreeStore(
+                object, str, str, int, str, str, str, str)
 
         self.port_list.set_sort_func(1000, cmp_port_list_addr)
         self.port_list.set_sort_column_id(1000, gtk.SORT_ASCENDING)
@@ -198,8 +241,10 @@ class HostOpenPorts(HIGVBox):
         # service icon host hostname port protocol state version
         # service is shown only when more than one service is selected (hence
         # host_tree not host_list is used).
-        self.host_list = gtk.ListStore(str, str, object, str, int, str, str, str)
-        self.host_tree = gtk.TreeStore(str, str, object, str, int, str, str, str)
+        self.host_list = gtk.ListStore(
+                str, str, object, str, int, str, str, str)
+        self.host_tree = gtk.TreeStore(
+                str, str, object, str, int, str, str, str)
 
         self.host_list.set_sort_func(1000, cmp_host_list_addr)
         self.host_list.set_sort_column_id(1000, gtk.SORT_ASCENDING)
@@ -254,7 +299,8 @@ class HostOpenPorts(HIGVBox):
         self.host_columns['state'].pack_start(self.cell_port, True)
 
         self.host_columns['service'].set_attributes(self.cell_port, text=0)
-        self.host_columns['icon'].set_attributes(self.cell_host_icon, stock_id=1)
+        self.host_columns['icon'].set_attributes(
+                self.cell_host_icon, stock_id=1)
         self.host_columns['hostname'].set_attributes(self.cell_port, text=3)
         self.host_columns['port_number'].set_attributes(self.cell_port, text=4)
         self.host_columns['protocol'].set_attributes(self.cell_port, text=5)
@@ -263,7 +309,8 @@ class HostOpenPorts(HIGVBox):
 
         self.host_columns['service'].set_visible(False)
 
-        self.scroll_ports_hosts.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.scroll_ports_hosts.set_policy(
+                gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
 
     def _set_port_list(self):
         self.port_view.set_enable_search(True)
@@ -284,7 +331,6 @@ class HostOpenPorts(HIGVBox):
             self.port_columns[k].set_reorderable(True)
             self.port_columns[k].set_resizable(True)
 
-
         self.port_columns['icon'].set_min_width(35)
 
         self.port_columns['hostname'].set_sort_column_id(1000)
@@ -337,10 +383,14 @@ class HostOpenPorts(HIGVBox):
     def freeze(self):
         """Freeze notifications and sorting to make adding lots of elements to
         the model faster."""
-        self.frozen_host_list_sort_column_id = self.host_list.get_sort_column_id()
-        self.frozen_host_tree_sort_column_id = self.host_tree.get_sort_column_id()
-        self.frozen_port_list_sort_column_id = self.port_list.get_sort_column_id()
-        self.frozen_port_tree_sort_column_id = self.port_tree.get_sort_column_id()
+        self.frozen_host_list_sort_column_id = \
+                self.host_list.get_sort_column_id()
+        self.frozen_host_tree_sort_column_id = \
+                self.host_tree.get_sort_column_id()
+        self.frozen_port_list_sort_column_id = \
+                self.port_list.get_sort_column_id()
+        self.frozen_port_tree_sort_column_id = \
+                self.port_tree.get_sort_column_id()
         self.host_list.set_default_sort_func(lambda *args: -1)
         self.host_tree.set_default_sort_func(lambda *args: -1)
         self.port_list.set_default_sort_func(lambda *args: -1)
@@ -356,13 +406,17 @@ class HostOpenPorts(HIGVBox):
         """Restore notifications and sorting (after making changes to the
         model)."""
         if self.frozen_host_list_sort_column_id != (None, None):
-            self.host_list.set_sort_column_id(*self.frozen_host_list_sort_column_id)
+            self.host_list.set_sort_column_id(
+                    *self.frozen_host_list_sort_column_id)
         if self.frozen_host_tree_sort_column_id != (None, None):
-            self.host_tree.set_sort_column_id(*self.frozen_host_tree_sort_column_id)
+            self.host_tree.set_sort_column_id(
+                    *self.frozen_host_tree_sort_column_id)
         if self.frozen_port_list_sort_column_id != (None, None):
-            self.port_list.set_sort_column_id(*self.frozen_port_list_sort_column_id)
+            self.port_list.set_sort_column_id(
+                    *self.frozen_port_list_sort_column_id)
         if self.frozen_port_tree_sort_column_id != (None, None):
-            self.port_tree.set_sort_column_id(*self.frozen_port_tree_sort_column_id)
+            self.port_tree.set_sort_column_id(
+                    *self.frozen_port_tree_sort_column_id)
         self.host_view.set_model(self.frozen_host_view_model)
         self.port_view.set_model(self.frozen_port_view_model)
         self.host_view.thaw_child_notify()
@@ -383,7 +437,8 @@ class HostOpenPorts(HIGVBox):
         self.host_list.append(entry)
 
     def add_to_port_tree(self, host):
-        parent = self.port_tree.append(None, [host, host.get_hostname(), None, 0,'','','',''])
+        parent = self.port_tree.append(
+                None, [host, host.get_hostname(), None, 0, '', '', '', ''])
         for p in host.get_ports():
             self.port_tree.append(parent,
                 [None, '', findout_service_icon(p), int(p.get('portid', "0")),
@@ -391,12 +446,21 @@ class HostOpenPorts(HIGVBox):
                 p.get('service_name', _("Unknown")), get_version_string(p)])
 
     def add_to_host_tree(self, service_name, ports):
-        parent = self.host_tree.append(None, [service_name, '', None, '', 0, '', '', ''])
+        parent = self.host_tree.append(
+                None, [service_name, '', None, '', 0, '', '', ''])
         for p in ports:
             self.host_tree.append(parent,
-                ['', findout_service_icon(p), p["host"], p["host"].get_hostname(),
-                int(p.get('portid', "0")), p.get('protocol', ""),
-                p.get('port_state', _("Unknown")), get_version_string(p)])
+                    [
+                        '',
+                        findout_service_icon(p),
+                        p["host"],
+                        p["host"].get_hostname(),
+                        int(p.get('portid', "0")),
+                        p.get('protocol', ""),
+                        p.get('port_state', _("Unknown")),
+                        get_version_string(p)
+                    ]
+                )
 
     def switch_port_to_list_store(self):
         if self.port_view.get_model() != self.port_list:
